import request from '@/utils/request'

// 查询政策类别列表
export function listMenu(query) {
  return request({
    url: '/system/policy/list',
    method: 'get',
    params: query
  })
}

// 查询政策类别详细
export function getMenu(menuId) {
  return request({
    url: '/system/policy/' + menuId,
    method: 'get'
  })
}

export function listDeptExcludeChild(menuId) {
  return request({
    url: '/system/policy/list/exclude/' + menuId,
    method: 'get'
  })
}



// 新增政策类别
export function addMenu(data) {
  return request({
    url: '/system/policy',
    method: 'post',
    data: data
  })
}

// 修改政策类别
export function updateMenu(data) {
  return request({
    url: '/system/policy',
    method: 'put',
    data: data
  })
}

// 删除政策类别
export function delMenu(menuId) {
  return request({
    url: '/system/policy/' + menuId,
    method: 'delete'
  })
}
