<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="类别名称" prop="menuName">
        <el-input
          v-model="queryParams.menuName"
          placeholder="请输入类别名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:menu:add']"
        >新增</el-button>
      </el-col>
      <!-- <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:menu:edit']"
        >修改</el-button>
      </el-col> -->
      <!-- <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:menu:remove']"
        >删除</el-button>
      </el-col> -->
      <!-- <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['system:menu:export']"
        >导出</el-button>
      </el-col> -->
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

   <!-- <el-table v-loading="loading" :data="menuList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="类别ID" align="center" prop="menuId" />
      <el-table-column label="类别名称" align="center" prop="menuName" />
      <el-table-column label="类别简介" align="center" prop="menuIntroduce" />
      <el-table-column label="显示顺序" align="center" prop="orderNum" />
      <el-table-column label="类别状态" align="center" prop="visible">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.sys_show_hide" :value="scope.row.visible"/>
        </template>
      </el-table-column>
      <el-table-column label="类别状态" align="center" prop="status">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.sys_normal_disable" :value="scope.row.status"/>
        </template>
      </el-table-column>
      <el-table-column label="政策图标" align="center" prop="photo" />
      <el-table-column label="备注" align="center" prop="remark" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:menu:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:menu:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table> -->
    <el-table
      v-if="refreshTable"
      v-loading="loading"
      :data="menuList"
      row-key="menuId"
      :default-expand-all="isExpandAll"
      :tree-props="{children: 'children', hasChildren: 'hasChildren'}"
    >
      <el-table-column label="类别名称" align="center" prop="menuName" />
      <el-table-column label="类别简介" align="center" prop="menuIntroduce" />
      <el-table-column label="显示顺序" align="center" prop="orderNum" />
      <el-table-column label="类别状态" align="center" prop="visible">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.sys_show_hide" :value="scope.row.visible"/>
        </template>
      </el-table-column>
      <el-table-column label="类别状态" align="center" prop="status">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.sys_normal_disable" :value="scope.row.status"/>
        </template>
      </el-table-column>
      <!-- <el-table-column label="政策图标" align="center" prop="photo" /> -->
      <el-table-column label="政策图标" align="center" prop="photo" width="100">
        <template slot-scope="scope">
          <image-preview :src="scope.row.photo" :width="50" :height="50"/>
        </template>
      </el-table-column>
      <el-table-column label="备注" align="center" prop="remark" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:menu:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:menu:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <!-- <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
 -->
    <!-- 添加或修改政策类别对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="800px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-row>
          <el-col :span="12">
<el-form-item label="类别名称" prop="menuName">
          <el-input v-model="form.menuName" placeholder="请输入类别名称" />
        </el-form-item>
          </el-col>
          
          <el-col :span="12" v-if="form.parentId !== 0">
          <el-form-item label="上级类别" prop="parentId">
            <treeselect v-model="form.parentId" :options="deptOptions" :normalizer="normalizer"  placeholder="请选择上级类别" />
          </el-form-item>
          </el-col>
          
          <el-col :span="12">
          <el-form-item label="显示顺序" prop="orderNum">
            <el-input v-model="form.orderNum" type="number" placeholder="请输入显示顺序" />
          </el-form-item>
          </el-col>
          <el-col :span="12">
          <el-form-item label="是否显示" prop="visible">
            <!-- <el-input v-model="form.visible" placeholder="请输入类别状态" /> -->
            <el-select v-model="form.visible" placeholder="是否显示"  style="width: 100%;">
              <el-option
                v-for="dict in dict.type.sys_show_hide"
                :key="dict.value"
                :label="dict.label"
                :value="dict.value"
              />
            </el-select>
          </el-form-item>
          </el-col>

          <el-col :span="12">
          <el-form-item label="类别简介" prop="menuIntroduce">
            <el-input v-model="form.menuIntroduce" type="textarea" placeholder="请输入内容" />
          </el-form-item>
          </el-col>
          <el-col :span="12">
          <el-form-item label="类别状态">
                    <el-radio-group v-model="form.status">
                      <el-radio
                        v-for="dict in dict.type.sys_normal_disable"
                        :key="dict.value"
          :label="dict.value"
                      >{{dict.label}}</el-radio>
                    </el-radio-group>
                  </el-form-item>
          </el-col>


          <el-col :span="24">
          <el-form-item label="政策图标" prop="photo">
            <image-upload v-model="form.photo"/>
          </el-form-item>
          </el-col>

          <el-col :span="24">
          <el-form-item label="备注" prop="remark">
            <el-input v-model="form.remark" type="textarea" placeholder="请输入内容" />
          </el-form-item>
          </el-col>
          <el-col :span="12">

          </el-col>
          <el-col :span="12">

          </el-col>
        </el-row>








      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listMenu, getMenu, delMenu, addMenu, updateMenu,listDeptExcludeChild } from "@/api/settlement/menutwo";
import { treeselect } from "@/api/system/dept";
import Treeselect from "@riophae/vue-treeselect";
import "@riophae/vue-treeselect/dist/vue-treeselect.css";
export default {
  name: "Menu",
  dicts: ['sys_normal_disable','sys_yes_no','sys_show_hide'],
  components: { Treeselect },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 部门树选项
      deptOptions: undefined,
      // 政策类别表格数据
      menuList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        menuName: null,
      },
      // 表单参数
      form: {},
      // 重新渲染表格状态
      refreshTable: true,
      // 是否展开，默认全部展开
      isExpandAll: true,
      // 表单校验
      rules: {
        menuName: [
          { required: true, message: "类别名称不能为空", trigger: "blur" }
        ],
        menuIntroduce: [
          { required: true, message: "类别简介不能为空", trigger: "blur" }
        ],
        orderNum: [
          { required: true, message: "显示顺序不能为空", trigger: "blur" }
        ],
        photo: [
          { required: true, message: "政策图标不能为空", trigger: "blur" }
        ]
      }
    };
  },
  created() {
    this.getList();
    // this.getTreeselect()
  },
  methods: {
    /** 查询政策类别列表 */
    getList() {
      this.loading = true;
      listMenu(this.queryParams).then(response => {
        // this.menuList = response.rows;
        this.menuList = this.handleTree(response.data, "menuId");
        // this.deptOptions = this.handleTree(response.data, "menuId")
        console.log(this.deptOptions)
        // this.total = response.total;
        this.loading = false;
      });
    },
    /** 查询部门下拉树结构 */
    getTreeselect() {
      treeselect().then(response => {
        this.deptOptions = response.data;
      });
    },
    /** 转换部门数据结构 */
    normalizer(node) {
      if (node.children && !node.children.length) {
        delete node.children;
      }
      return {
        id: node.menuId,
        label: node.menuName,
        children: node.children
      };
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        menuId: null,
        menuName: null,
        menuIntroduce: null,
        parentId: null,
        orderNum: null,
        visible: '0',
        status: "0",
        photo: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null
      };
      this.resetForm("form");
    },
    /** 展开/折叠操作 */
    toggleExpandAll() {
      this.refreshTable = false;
      this.isExpandAll = !this.isExpandAll;
      this.$nextTick(() => {
        this.refreshTable = true;
      });
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.menuId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.reset();
      // if (row != undefined) {
      //   this.form.parentId = row.menuId;
      // }
      this.open = true;
      this.title = "添加政策类别";
      listMenu().then(response => {
        // this.menuList = response.rows;
        this.deptOptions = this.handleTree(response.data, "menuId")
        console.log(this.deptOptions)
        // this.total = response.total;
      });

    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const menuId = row.menuId || this.ids
      getMenu(row.menuId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改政策类别";
      });

      listDeptExcludeChild(row.menuId).then(response => {
        this.deptOptions = this.handleTree(response.data, "menuId");
        console.log(this.form.menuId,this.form.parentId)
      });

    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.menuId != null) {
            updateMenu(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addMenu(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const menuIds = row.menuId || this.ids;
      this.$modal.confirm('是否确认删除政策类别编号为"' + menuIds + '"的数据项？').then(function() {
        return delMenu(menuIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/menu/export', {
        ...this.queryParams
      }, `menu_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
